# pdb4all
*Convert between common protein pdb formats and names*

### Installation
Requires `python 3.7+`. No additional dependencies are needed. \
It should work on 2.7+ but no warranty is provided.

*pdb4all* is frequently uploaded to [PyPI](https://pypi.org/project/pdb4all/). To install it, execute the following command:
```
  pip install pdb4all
```

### Usage
```
  pdb4all <options> .pdb
```

#### Currently supported ForceFields name conventions
  * Amber
  * Charmm
  * OPLS

#### Currently supported formats (software)
  * Fasta
  * Maestro
  * GROMACS
  * fDynamo
